---
id: quickstart
title: Quickstart
---

You can easily try Research Graph using the following notebook:

[Open sample.ipynb on Google Colab](https://colab.research.google.com/github/auto-res/researchgraph/blob/main/notebook/sample.ipynb)

This notebook allows you to quickly execute and experiment with the features of AIRAS.
